translate.filters.helpers

Package translate :: Package filters :: Module helpers |
[hide private]
[frames] | no frames]

# Module helpers

source code

a set of helper functions for filters...

Functions | [hide private]
countmatch(str1, str2, countstr) checks whether countstr occurs the same number of times in str1 and str2 | source code
funcmatch(str1, str2, func, *args) returns whether the result of func is the same for str1 and str2 | source code
countsmatch(str1, str2, countlist) checks whether each element in countlist occurs the same number of times in str1 and str2 | source code
funcsmatch(str1, str2, funclist) checks whether the results of each func in funclist match for str1 and str2 | source code
filtercount(str1, func) returns the number of characters in str1 that pass func | source code
filtertestmethod(testmethod, strfilter) returns a version of the testmethod that operates on filtered strings using strfilter | source code
multifilter(str1, strfilters, *args) passes str1 through a list of filters | source code
multifiltertestmethod(testmethod, strfilters) returns a version of the testmethod that operates on filtered strings using strfilter | source code

Variables | [hide private]
| __package__ = ``'``translate.filters``'``

Imports: operator